@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,9 +10,7 @@ GearyAddressBook::GearyAddressBook(const QString &filename)
 {
 }
 
-GearyAddressBook::~GearyAddressBook()
-{
-}
+GearyAddressBook::~GearyAddressBook() = default;
 
 void GearyAddressBook::importAddressBook()
 {
