@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -269,7 +269,9 @@ void GMXImportExportPluginInterface::doExport(QFile *fp, const KContacts::Addres
 
         for (int recId = 0; recId < 3; ++recId) {
             KContacts::Address address;
-            KContacts::PhoneNumber phone, fax, cell;
+            KContacts::PhoneNumber phone;
+            KContacts::PhoneNumber fax;
+            KContacts::PhoneNumber cell;
 
             // address preference flag:
             // & 1: preferred email address
@@ -437,7 +439,8 @@ void GMXImportExportPluginInterface::importGMX()
     QDateTime dt;
     QTextStream gmxStream(&file);
     gmxStream.setCodec("ISO 8859-1");
-    QString line, line2;
+    QString line;
+    QString line2;
     line = gmxStream.readLine();
     line2 = gmxStream.readLine();
     if (!line.startsWith(QLatin1String("AB_ADDRESSES:")) || !line2.startsWith(QLatin1String("Address_id"))) {
@@ -548,11 +551,11 @@ void GMXImportExportPluginInterface::importGMX()
             if (!itemList[8].isEmpty()) {
                 addressee->insertPhoneNumber(KContacts::PhoneNumber(itemList[8], cellType));
             }
-            bool preferred = false;
+            KContacts::Email email(itemList[10]);
             if (itemList[19].toInt() & 1) {
-                preferred = true;
+                email.setPreferred(true);
             }
-            addressee->insertEmail(itemList[10], preferred);
+            addressee->addEmail(email);
             if (!itemList[11].isEmpty()) {
                 KContacts::ResourceLocatorUrl url;
                 url.setUrl(QUrl(itemList[11]));
