@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -87,9 +87,7 @@ MergeContactWidget::MergeContactWidget(QWidget *parent)
     connect(mMergeButton, &QPushButton::clicked, this, &MergeContactWidget::slotMergeContacts);
 }
 
-MergeContactWidget::~MergeContactWidget()
-{
-}
+MergeContactWidget::~MergeContactWidget() = default;
 
 void MergeContactWidget::setContacts(const Akonadi::Item::List &items)
 {
