@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,9 +27,7 @@ MergeContactSelectListWidget::MergeContactSelectListWidget(QWidget *parent)
     vbox->addWidget(mSelectListWidget);
 }
 
-MergeContactSelectListWidget::~MergeContactSelectListWidget()
-{
-}
+MergeContactSelectListWidget::~MergeContactSelectListWidget() = default;
 
 void MergeContactSelectListWidget::setContacts(MergeContacts::ConflictInformation conflictType, const KContacts::Addressee::List &lst)
 {
