@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ void MarkdownCreateLinkWidgetTest::shouldHaveDefaultValue()
 
     auto mainLayout = w.findChild<QFormLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
+    QCOMPARE(mainLayout->contentsMargins(), QMargins());
 
     auto mTitle = w.findChild<QLineEdit *>(QStringLiteral("title"));
     QVERIFY(mTitle);
