@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,7 +22,7 @@ private:
     void writeConfig();
     void readConfig();
     void slotEnabledOkButton(bool enabled);
-    MarkdownCreateLinkWidget *mMarkdownCreateLinkWidget = nullptr;
+    MarkdownCreateLinkWidget *const mMarkdownCreateLinkWidget;
     QPushButton *mOkButton = nullptr;
 };
 
