@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ AutoCorrectionPluginEditorInterface::AutoCorrectionPluginEditorInterface(QObject
 {
 }
 
-AutoCorrectionPluginEditorInterface::~AutoCorrectionPluginEditorInterface()
-{
-}
+AutoCorrectionPluginEditorInterface::~AutoCorrectionPluginEditorInterface() = default;
 
 void AutoCorrectionPluginEditorInterface::createAction(KActionCollection *ac)
 {
