@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TRIOPABSHORTURLENGINEPLUGIN_H
-#define TRIOPABSHORTURLENGINEPLUGIN_H
+#pragma once
 
 #include "../shorturlengineplugin.h"
 
@@ -22,4 +21,3 @@ public:
     QString engineName() const override;
 };
 
-#endif // TRIOPABSHORTURLENGINEPLUGIN_H
