@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ InsertSpecialCharacterPluginEditorInterfaceTest::InsertSpecialCharacterPluginEdi
 {
 }
 
-InsertSpecialCharacterPluginEditorInterfaceTest::~InsertSpecialCharacterPluginEditorInterfaceTest()
-{
-}
+InsertSpecialCharacterPluginEditorInterfaceTest::~InsertSpecialCharacterPluginEditorInterfaceTest() = default;
 
 void InsertSpecialCharacterPluginEditorInterfaceTest::shouldHaveDefaultValue()
 {
