@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ AutomaticAddContactsInterface::AutomaticAddContactsInterface(QObject *parent)
 {
 }
 
-AutomaticAddContactsInterface::~AutomaticAddContactsInterface()
-{
-}
+AutomaticAddContactsInterface::~AutomaticAddContactsInterface() = default;
 
 bool AutomaticAddContactsInterface::exec(const MessageComposer::PluginEditorCheckBeforeSendParams &params)
 {
