@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ CheckDuplicateEmailsDialogTest::CheckDuplicateEmailsDialogTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-CheckDuplicateEmailsDialogTest::~CheckDuplicateEmailsDialogTest()
-{
-}
+CheckDuplicateEmailsDialogTest::~CheckDuplicateEmailsDialogTest() = default;
 
 void CheckDuplicateEmailsDialogTest::shouldHaveDefaultValue()
 {
