@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ public:
     ~ConfirmAddressConfigureDialog() override;
 
 protected:
-    QWidget *createLayout() override;
+    Q_REQUIRED_RESULT QWidget *createLayout() override;
     void save() override;
     void load() override;
     void reset() override;
