@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,13 +9,9 @@
 #include <QJsonArray>
 #include <QJsonObject>
 
-LanguageToolListOfLanguagesParser::LanguageToolListOfLanguagesParser()
-{
-}
+LanguageToolListOfLanguagesParser::LanguageToolListOfLanguagesParser() = default;
 
-LanguageToolListOfLanguagesParser::~LanguageToolListOfLanguagesParser()
-{
-}
+LanguageToolListOfLanguagesParser::~LanguageToolListOfLanguagesParser() = default;
 
 QVector<LanguageInfo> LanguageToolListOfLanguagesParser::parseResult(const QJsonArray &array) const
 {
