@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include "transportconfigwidget.h"
+#include <MailTransport/TransportConfigWidget>
 
 namespace MailTransport
 {
