@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "emailaddressselectionldapdialog.h"
-#include <Akonadi/Contact/RecipientsPickerWidget>
+#include <Akonadi/RecipientsPickerWidget>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
