@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PGPKEYFORMATTER_H_
-#define PGPKEYFORMATTER_H_
+#pragma once
 
 #include <MessageViewer/MessagePartRendererBase>
 #include <MimeTreeParser/BodyPartFormatter>
@@ -21,7 +20,6 @@ public:
     bool render(const MimeTreeParser::MessagePartPtr &msgPart, MessageViewer::HtmlWriter *htmlWriter, MessageViewer::RenderContext *context) const override;
 
 private:
-    QString render(const PgpKeyMessagePart &mp) const;
+    Q_REQUIRED_RESULT QString render(const PgpKeyMessagePart &mp) const;
 };
 
-#endif
