@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ GravatarConfigureSettingsPluginDialog::GravatarConfigureSettingsPluginDialog(QWi
     initLayout(true);
 }
 
-GravatarConfigureSettingsPluginDialog::~GravatarConfigureSettingsPluginDialog()
-{
-}
+GravatarConfigureSettingsPluginDialog::~GravatarConfigureSettingsPluginDialog() = default;
 
 QWidget *GravatarConfigureSettingsPluginDialog::createLayout()
 {
