@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,9 +27,7 @@ ScamConfigureSettingsWidget::ScamConfigureSettingsWidget(QWidget *parent)
     mTreeWidget->setHeaderLabels({i18n("Domain"), i18n("Check")});
 }
 
-ScamConfigureSettingsWidget::~ScamConfigureSettingsWidget()
-{
-}
+ScamConfigureSettingsWidget::~ScamConfigureSettingsWidget() = default;
 
 void ScamConfigureSettingsWidget::loadSettings()
 {
