@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef HEADERSTYLEPLUGINTESTUTILS_H
-#define HEADERSTYLEPLUGINTESTUTILS_H
+#pragma once
 
 #include <KMime/Message>
 #include <QString>
@@ -13,4 +12,3 @@
 void testHeaderFile(const QString &data, const QString &name, const QString &dir = QString());
 KMime::Message::Ptr readAndParseMail(const QString &mailFile);
 
-#endif // HEADERSTYLEPLUGINTESTUTILS_H
