@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ ViewerPluginManagerTest::ViewerPluginManagerTest(QObject *parent)
 {
 }
 
-ViewerPluginManagerTest::~ViewerPluginManagerTest()
-{
-}
+ViewerPluginManagerTest::~ViewerPluginManagerTest() = default;
 
 void ViewerPluginManagerTest::shouldHaveDefaultValue()
 {
