@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ SelectImapFolderWidgetTest::SelectImapFolderWidgetTest(QObject *parent)
 {
 }
 
-SelectImapFolderWidgetTest::~SelectImapFolderWidgetTest()
-{
-}
+SelectImapFolderWidgetTest::~SelectImapFolderWidgetTest() = default;
 
 void SelectImapFolderWidgetTest::shouldHaveDefaultValue()
 {
@@ -27,7 +25,7 @@ void SelectImapFolderWidgetTest::shouldHaveDefaultValue()
     SelectImapFolderWidget w(account);
     auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
+    QCOMPARE(mainLayout->contentsMargins(), QMargins());
 
     auto mTreeView = w.findChild<QTreeView *>(QStringLiteral("treeview"));
     QVERIFY(mTreeView);
