@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,9 +29,7 @@ SelectImapWidgetTest::SelectImapWidgetTest(QWidget *parent)
     mainLayout->addWidget(lineEdit);
 }
 
-SelectImapWidgetTest::~SelectImapWidgetTest()
-{
-}
+SelectImapWidgetTest::~SelectImapWidgetTest() = default;
 
 DefaultMoveImapFolderWidget::DefaultMoveImapFolderWidget(QWidget *parent)
     : KSieveUi::AbstractMoveImapFolderWidget(parent)
